pub struct Document {
pub tree: Tree,
pub errors: RefCell<Vec<Cow<'static, str>>>,
pub quirks_mode: Cell<QuirksMode>,
}Expand description
Document represents an HTML document to be manipulated.
Fields
tree: TreeThe document’s dom tree.
errors: RefCell<Vec<Cow<'static, str>>>Errors that occurred during parsing.
quirks_mode: Cell<QuirksMode>The document’s quirks mode.
Implementations
Sourceimpl Document
impl Document
Sourcepub fn html(&self) -> Tendril<UTF8>
pub fn html(&self) -> Tendril<UTF8>
Gets the HTML contents of the document. It includes the text and comment nodes.
Sourcepub fn inner_html(&self) -> Tendril<UTF8>
pub fn inner_html(&self) -> Tendril<UTF8>
Gets the HTML contents of the document. It includes only children nodes.
Sourcepub fn try_html(&self) -> Option<Tendril<UTF8>>
pub fn try_html(&self) -> Option<Tendril<UTF8>>
Gets the HTML contents of the document. It includes its children nodes.
Sourcepub fn try_inner_html(&self) -> Option<Tendril<UTF8>>
pub fn try_inner_html(&self) -> Option<Tendril<UTF8>>
Gets the HTML contents of the document. It includes only children nodes.
Sourcepub fn formatted_text(&self) -> Tendril<UTF8>
pub fn formatted_text(&self) -> Tendril<UTF8>
Returns the formatted text of the document and its descendants. This is the same as
the text() method, but with a few differences:
- Whitespace is normalized so that there is only one space between words.
- All whitespace is removed from the beginning and end of the text.
- After block elements, a double newline is added.
- For elements like
br, ‘hr’, ‘li’, ‘tr’ a single newline is added.
Sourcepub fn base_uri(&self) -> Option<Tendril<UTF8>>
pub fn base_uri(&self) -> Option<Tendril<UTF8>>
Finds the base URI of the tree by looking for <base> tags in document’s head.
The base URI is the value of the href attribute of the first
<base> tag in the document’s head. If no such tag is found,
the method returns None.
Sourcepub fn body(&self) -> Option<NodeRef<'_>>
pub fn body(&self) -> Option<NodeRef<'_>>
Returns the document’s <body> element, or None if absent.
For fragments (crate::NodeData::Fragment), this typically returns None.
Sourcepub fn head(&self) -> Option<NodeRef<'_>>
pub fn head(&self) -> Option<NodeRef<'_>>
Returns the document’s <head> element, or None if absent.
For fragments (crate::NodeData::Fragment), this typically returns None.
Sourcepub fn normalize(&self)
pub fn normalize(&self)
Merges adjacent text nodes and removes empty text nodes.
Normalization is necessary to ensure that adjacent text nodes are merged into one text node.
Example
use dom_query::Document;
let doc = Document::from("<div>Hello</div>");
let sel = doc.select("div");
let div = sel.nodes().first().unwrap();
let text1 = doc.tree.new_text(" ");
let text2 = doc.tree.new_text("World");
let text3 = doc.tree.new_text("");
div.append_child(&text1);
div.append_child(&text2);
div.append_child(&text3);
assert_eq!(div.children().len(), 4);
doc.normalize();
assert_eq!(div.children().len(), 1);
assert_eq!(div.text(), "Hello World".into());Sourceimpl Document
impl Document
Sourcepub fn select(&self, sel: &str) -> Selection<'_>
pub fn select(&self, sel: &str) -> Selection<'_>
Gets the descendants of the root document node in the current, filter by a selector. It returns a new selection object containing these matched elements.
Panics
Panics if failed to parse the given CSS selector.
Sourcepub fn nip(&self, sel: &str) -> Selection<'_>
pub fn nip(&self, sel: &str) -> Selection<'_>
Alias for select, it gets the descendants of the root document node in the current, filter by a selector.
It returns a new selection object containing these matched elements.
Panics
Panics if failed to parse the given CSS selector.
Sourcepub fn try_select(&self, sel: &str) -> Option<Selection<'_>>
pub fn try_select(&self, sel: &str) -> Option<Selection<'_>>
Gets the descendants of the root document node in the current, filter by a selector. It returns a new selection object containing these matched elements.
Sourcepub fn select_matcher(&self, matcher: &Matcher) -> Selection<'_>
pub fn select_matcher(&self, matcher: &Matcher) -> Selection<'_>
Gets the descendants of the root document node in the current, filter by a matcher. It returns a new selection object containing these matched elements.
Sourcepub fn select_single_matcher(&self, matcher: &Matcher) -> Selection<'_>
pub fn select_single_matcher(&self, matcher: &Matcher) -> Selection<'_>
Gets the descendants of the root document node in the current, filter by a matcher. It returns a new selection object containing elements of the single (first) match.
Sourcepub fn select_single(&self, sel: &str) -> Selection<'_>
pub fn select_single(&self, sel: &str) -> Selection<'_>
Gets the descendants of the root document node in the current, filter by a selector. It returns a new selection object containing elements of the single (first) match.
Panics
Panics if failed to parse the given CSS selector.
Sourceimpl Document
impl Document
Sourcepub fn md(&self, skip_tags: Option<&[&str]>) -> Tendril<UTF8>
pub fn md(&self, skip_tags: Option<&[&str]>) -> Tendril<UTF8>
Produces a Markdown representation of the Document,
skipping elements matching the specified skip_tags list along with their descendants.
- If
skip_tagsisNone, the default list is used:["script", "style", "meta", "head"]. - To process all elements without exclusions, pass
Some(&[]).